==> wsoundserver_0.2.2.orig.tar.gz: WSoundServer-0.2.2/wslib/application.c <==
/*

Sound audio library
   
Copyright (c) 1999 Pascal Hofstee & Alain Kalker
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

$Id: application.c,v 1.2 1999/07/24 22:01:14 daeron Exp $

*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "wsound.h"

#include <assert.h>


char*	_wslib_progname = NULL;



Bool
SAppicationInitialized(void)
{
	    return _wslib_progname != NULL;
}


void
SInitializeApplication(char *applicationName)
{
	assert(applicationName != NULL);
	
	_wslib_progname = applicationName;
}

==> wsoundserver_0.4.0.orig.tar.gz: WSoundServer-0.4.0/wslib/application.c <==
/*

Sound audio library
   
Copyright (c) 1999 Pascal Hofstee & Alain Kalker
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

$Id: application.c,v 1.10 1999/11/07 16:43:21 daeron Exp $

*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "wsound.h"

#include <assert.h>


char*	_wslib_progname = NULL;



Bool
SAppicationInitialized(void)
{
	    return _wslib_progname != NULL;
}


void
SInitializeApplication(char *applicationName)
{
	assert(applicationName != NULL);
	
	_wslib_progname = applicationName;
	
	if (!WMSoundDBLoaded) {
		SLoadConfig();
		WMSoundDBLoaded = True;

#if defined (HAVE_GSDD)
		PLRegister(WMSoundDB, SSyncConfig);
#endif
	}
}

void
SShutdownApplication(void) {
	if (WMSoundDBLoaded) {
#if defined (HAVE_GSDD)
		PLUnregister(WMSoundDB);
#endif
		PLRelease(WMSoundDB);
		WMSoundDBLoaded = False;
	}
}
